translate.storage.tiki

Package translate :: Package storage :: Module tiki |
[hide private]
[frames] | no frames]

# Module tiki

source code

Class that manages TikiWiki files for translation. Tiki files are <strike>ugly and inconsistent</strike> formatted as a single large PHP array with several special sections identified by comments. Example current as of 2008-12-01:

     <?php
       // Many comments at the top
       $lang=Array(
       // ### Start of unused words
       "aaa" => "zzz",
       // ### end of unused words

       // ### start of untranslated words
       // "bbb" => "yyy",
       // ### end of untranslated words

       // ### start of possibly untranslated words
       "ccc" => "xxx",
       // ### end of possibly untranslated words

       "ddd" => "www",
       "###end###"=>"###end###");
     ?>

In addition there are several auto-generated //-style comments scattered through the page and array, some of which matter when being parsed.

This has all been gleaned from the TikiWiki source. As far as I know no detailed documentation exists for the tiki language.php files.

Classes | [hide private]
| TikiUnit A tiki unit entry.
| TikiStore Represents a tiki language.php file.

Imports: base, wStringIO, re, datetime